@@ -1,12 +1,17 @@
 # coding: utf-8
 from __future__ import absolute_import, unicode_literals
+
+import warnings
+from collections import OrderedDict
+from itertools import islice
+
+import six
+from django import VERSION as django_version
 from django.db.models.fields import FieldDoesNotExist
-from django.utils.datastructures import SortedDict
-from django.utils.safestring import SafeData
 from django_tables2.templatetags.django_tables2 import title
 from django_tables2.utils import A, AttributeDict, OrderBy, OrderByTuple
-from itertools import ifilter, islice
-import warnings
+
+from ..utils import python_2_unicode_compatible
 
 
 class Library(object):
@@ -75,7 +80,7 @@ class Column(object):  # pylint: disable=R0902
         An accessor that describes how to extract values for this column from
         the :term:`table data`.
 
-        :type: `basestring` or `~.Accessor`
+        :type: string or `~.Accessor`
 
 
     .. attribute:: default
@@ -115,15 +120,26 @@ class Column(object):  # pylint: disable=R0902
 
         :type: `unicode`
 
-        This should not defined in title case, but rather natural case. It is
-        converted to title case for use in column headers.
-
 
     .. attribute:: visible
 
         If `True`, this column will be included in the HTML output.
 
         :type: `bool`
+
+
+    .. attribute:: localize
+
+        *   If `True`, cells of this column will be localized in the HTML output
+            by the localize filter.
+
+        *   If `False`, cells of this column will be unlocalized in the HTML output
+            by the unlocalize filter.
+
+        *   If `None` (the default), cell will be rendered as is and localization will depend
+            on ``USE_L10N`` setting.
+
+        :type: `bool`
     """
     #: Tracks each time a Column instance is created. Used to retain order.
     creation_counter = 0
@@ -131,8 +147,8 @@ class Column(object):  # pylint: disable=R0902
 
     def __init__(self, verbose_name=None, accessor=None, default=None,
                  visible=True, orderable=None, attrs=None, order_by=None,
-                 sortable=None, empty_values=None):
-        if not (accessor is None or isinstance(accessor, basestring) or
+                 sortable=None, empty_values=None, localize=None):
+        if not (accessor is None or isinstance(accessor, six.string_types) or
                 callable(accessor)):
             raise TypeError('accessor must be a string or callable, not %s' %
                             type(accessor).__name__)
@@ -151,11 +167,13 @@ class Column(object):  # pylint: disable=R0902
         self.orderable = orderable
         self.attrs = attrs or {}
         # massage order_by into an OrderByTuple or None
-        order_by = (order_by, ) if isinstance(order_by, basestring) else order_by
+        order_by = (order_by, ) if isinstance(order_by, six.string_types) else order_by
         self.order_by = OrderByTuple(order_by) if order_by is not None else None
         if empty_values is not None:
             self.empty_values = empty_values
 
+        self.localize = localize
+
         self.creation_counter = Column.creation_counter
         Column.creation_counter += 1
 
@@ -169,9 +187,7 @@ class Column(object):  # pylint: disable=R0902
         """
         The value used for the column heading (e.g. inside the ``<th>`` tag).
 
-        By default this titlises the `~.Column.verbose_name`. If
-        `~.Column.verbose_name` is an instance of `~.safestring.SafeData`, it's
-        used unmodified.
+        By default this returns `~.Column.verbose_name`.
 
         :returns: `unicode` or `None`
 
@@ -184,12 +200,7 @@ class Column(object):  # pylint: disable=R0902
             accessing that first) when this property doesn't return something
             useful.
         """
-        if self.verbose_name:
-            if isinstance(self.verbose_name, SafeData):
-                # If the author has used mark_safe, we're going to assume the
-                # author wants the value used verbatim.
-                return self.verbose_name
-            return title(self.verbose_name)
+        return self.verbose_name
 
     def render(self, value):
         """
@@ -234,9 +245,14 @@ class Column(object):  # pylint: disable=R0902
         # Since this method is inherited by every subclass, only provide a
         # column if this class was asked directly.
         if cls is Column:
-            return cls(verbose_name=field.verbose_name)
+            if hasattr(field, "get_related_field"):
+                verbose_name = field.get_related_field().verbose_name
+            else:
+                verbose_name = getattr(field, 'verbose_name', field.name)
+            return cls(verbose_name=verbose_name)
 
 
+@python_2_unicode_compatible
 class BoundColumn(object):
     """
     A *run-time* version of `.Column`. The difference between
@@ -251,7 +267,7 @@ class BoundColumn(object):
     :param  table: the table in which this column exists
     :type  column: `.Column` object
     :param column: the type of column
-    :type    name: `basestring` object
+    :type    name: string object
     :param   name: the variable name of the column used to when defining the
                    `.Table`. In this example the name is ``age``:
 
@@ -266,8 +282,8 @@ class BoundColumn(object):
         self.column = column
         self.name = name
 
-    def __unicode__(self):
-        return unicode(self.header)
+    def __str__(self):
+        return six.text_type(self.header)
 
     @property
     def accessor(self):
@@ -331,13 +347,7 @@ class BoundColumn(object):
         if column_header:
             return column_header
         # fall back to automatic best guess
-        verbose_name = self.verbose_name  # avoid calculating multiple times
-        if isinstance(verbose_name, SafeData):
-            # If the verbose_name has come from a model field, it's possible
-            # that the author used mark_safe to include HTML in the value. If
-            # this is the case, we leave it verbatim.
-            return verbose_name
-        return title(verbose_name)
+        return self.verbose_name
 
     @property
     def order_by(self):
@@ -434,7 +444,7 @@ class BoundColumn(object):
     @property
     def verbose_name(self):
         """
-        Return the verbose name for this column, or fallback to prettified
+        Return the verbose name for this column, or fallback to the titlised
         column name.
 
         If the table is using queryset data, then use the corresponding model
@@ -442,26 +452,28 @@ class BoundColumn(object):
         then get the last field in the accessor (i.e. stop when the
         relationship turns from ORM relationships to object attributes [e.g.
         person.upper should stop at person]).
-
-        If the model field's `~.db.Field.verbose_name` is a
-        `~.safestring.SafeData`, it's used unmodified.
         """
         # Favor an explicit defined verbose_name
-        if self.column.verbose_name:
+        if self.column.verbose_name is not None:
             return self.column.verbose_name
 
         # This is our reasonable fallback, should the next section not result
         # in anything useful.
-        name = self.name.replace('_', ' ')
+        name = title(self.name.replace('_', ' '))
 
-        # Try to use a tmodel field's verbose_name
-        if hasattr(self.table.data, 'queryset'):
+        # Try to use a model field's verbose_name
+        if hasattr(self.table.data, 'queryset') and hasattr(self.table.data.queryset, 'model'):
             model = self.table.data.queryset.model
             parts = self.accessor.split('.')
             field = None
             for part in parts:
+
                 try:
-                    field = model._meta.get_field(part)
+                    if django_version < (1, 8, 0):
+                        field, _, _, _ = model._meta.get_field_by_name(part)
+                    else:
+                        field = model._meta.get_field(part)
+
                 except FieldDoesNotExist:
                     break
                 if hasattr(field, 'rel') and hasattr(field.rel, 'to'):
@@ -469,7 +481,10 @@ class BoundColumn(object):
                     continue
                 break
             if field:
-                name = field.verbose_name
+                if hasattr(field, 'field'):
+                    name = field.field.verbose_name
+                else:
+                    name = getattr(field, 'verbose_name', field.name)
         return name
 
     @property
@@ -479,6 +494,13 @@ class BoundColumn(object):
         """
         return self.column.visible
 
+    @property
+    def localize(self):
+        '''
+        Returns `True`, `False` or `None` as described in ``Column.localize``
+        '''
+        return self.column.localize
+
 
 class BoundColumns(object):
     """
@@ -492,7 +514,7 @@ class BoundColumns(object):
     A `BoundColumns` object is a container for holding `BoundColumn` objects.
     It provides methods that make accessing columns easier than if they were
     stored in a `list` or `dict`. `Columns` has a similar API to a `dict` (it
-    actually uses a `~django.utils.datastructures.SortedDict` interally).
+    actually uses a `~collections.OrderedDict` interally).
 
     At the moment you'll only come across this class when you access a
     `.Table.columns` property.
@@ -502,8 +524,8 @@ class BoundColumns(object):
     """
     def __init__(self, table):
         self.table = table
-        self.columns = SortedDict()
-        for name, column in table.base_columns.iteritems():
+        self.columns = OrderedDict()
+        for name, column in six.iteritems(table.base_columns):
             self.columns[name] = bc = BoundColumn(table, column, name)
             bc.render = getattr(table, 'render_' + name, column.render)
 
@@ -548,7 +570,7 @@ class BoundColumns(object):
         conjunction with e.g. ``{{ forloop.last }}`` (the last column might not
         be the actual last that is rendered).
         """
-        return ifilter(lambda x: x.orderable, self.iterall())
+        return (x for x in self.iterall() if x.orderable)
 
     def itersortable(self):
         warnings.warn('`itersortable` is deprecated, use `iterorderable` instead.',
@@ -570,7 +592,7 @@ class BoundColumns(object):
 
         This is geared towards table rendering.
         """
-        return ifilter(lambda x: x.visible, self.iterall())
+        return (x for x in self.iterall() if x.visible)
 
     def visible(self):
         return list(self.itervisible())
@@ -587,7 +609,7 @@ class BoundColumns(object):
 
         *item* can either be a `BoundColumn` object, or the name of a column.
         """
-        if isinstance(item, basestring):
+        if isinstance(item, six.string_types):
             return item in self.iternames()
         else:
             # let's assume we were given a column
@@ -616,7 +638,7 @@ class BoundColumns(object):
                 return next(islice(self.iterall(), index, index + 1))
             except StopIteration:
                 raise IndexError
-        elif isinstance(index, basestring):
+        elif isinstance(index, six.string_types):
             for column in self.iterall():
                 if column.name == index:
                     return column
