@@ -1,19 +1,22 @@
 # coding: utf-8
 from __future__ import unicode_literals
+
+import copy
+import warnings
+from collections import OrderedDict
+
+import six
+from django import VERSION
+from django.core.paginator import Paginator
+from django.db.models.fields import FieldDoesNotExist
+from django.template import RequestContext
+from django.template.loader import get_template
+
 from . import columns
 from .config import RequestConfig
 from .rows import BoundRows
-from .utils import (Accessor, AttributeDict, build_request, cached_property,
-                    computed_values, OrderBy, OrderByTuple, segment, Sequence)
-import copy
-from django.core.paginator       import Paginator
-from django.db.models.fields     import FieldDoesNotExist
-from django.utils.datastructures import SortedDict
-from django.template             import RequestContext
-from django.template.loader      import get_template
-import six
-import warnings
-
+from .utils import (Accessor, AttributeDict, OrderBy, OrderByTuple, Sequence,
+                    cached_property, computed_values, segment)
 
 QUERYSET_ACCESSOR_SEPARATOR = '__'
 
@@ -34,12 +37,15 @@ class TableData(object):
             self.queryset = data
         # otherwise it must be convertable to a list
         else:
-            try:
+            # do some light validation
+            if hasattr(data, '__iter__') or (hasattr(data, '__len__') and hasattr(data, '__getitem__')):
                 self.list = list(data)
-            except:
-                raise ValueError('data must be QuerySet-like (have count and '
-                                 'order_by) or support list(data) -- %s has '
-                                 'neither' % type(data).__name__)
+            else:
+                raise ValueError(
+                    'data must be QuerySet-like (have count and '
+                    'order_by) or support list(data) -- %s has '
+                    'neither' % type(data).__name__
+                )
 
     def __len__(self):
         if not hasattr(self, "_length"):
@@ -97,7 +103,8 @@ class TableData(object):
                 accessors += bound_column.order_by
         if hasattr(self, "queryset"):
             translate = lambda accessor: accessor.replace(Accessor.SEPARATOR, QUERYSET_ACCESSOR_SEPARATOR)
-            self.queryset = self.queryset.order_by(*(translate(a) for a in accessors))
+            if accessors:
+                self.queryset = self.queryset.order_by(*(translate(a) for a in accessors))
         else:
             self.list.sort(key=OrderByTuple(accessors).key)
 
@@ -168,10 +175,10 @@ class DeclarativeColumnsMetaclass(type):
             if hasattr(base, "base_columns"):
                 parent_columns = list(base.base_columns.items()) + parent_columns
         # Start with the parent columns
-        attrs["base_columns"] = SortedDict(parent_columns)
+        attrs["base_columns"] = OrderedDict(parent_columns)
         # Possibly add some generated columns based on a model
         if opts.model:
-            extra = SortedDict()
+            extra = OrderedDict()
             # honor Table.Meta.fields, fallback to model._meta.fields
             if opts.fields:
                 # Each item in opts.fields is the name of a model field or a
@@ -190,7 +197,7 @@ class DeclarativeColumnsMetaclass(type):
             attrs["base_columns"].update(extra)
 
         # Explicit columns override both parent and generated columns
-        attrs["base_columns"].update(SortedDict(cols))
+        attrs["base_columns"].update(OrderedDict(cols))
         # Apply any explicit exclude setting
         for exclusion in opts.exclude:
             if exclusion in attrs["base_columns"]:
@@ -200,7 +207,7 @@ class DeclarativeColumnsMetaclass(type):
             opts.sequence.expand(attrs["base_columns"].keys())
             # Table's sequence defaults to sequence declared in Meta
             #attrs['_sequence'] = opts.sequence
-            attrs["base_columns"] = SortedDict(((x, attrs["base_columns"][x]) for x in opts.sequence))
+            attrs["base_columns"] = OrderedDict(((x, attrs["base_columns"][x]) for x in opts.sequence))
 
         # set localize on columns
         for col_name in attrs["base_columns"].keys():
@@ -243,6 +250,7 @@ class TableOptions(object):
         self.per_page = getattr(options, "per_page", 25)
         self.per_page_field = getattr(options, "per_page_field", "per_page")
         self.prefix = getattr(options, "prefix", "")
+        self.show_header = getattr(options, "show_header", True)
         self.sequence = Sequence(getattr(options, "sequence", ()))
         if hasattr(options, "sortable"):
             warnings.warn("`Table.Meta.sortable` is deprecated, use `orderable` instead",
@@ -253,7 +261,6 @@ class TableOptions(object):
         self.localize = getattr(options, "localize", ())
         self.unlocalize = getattr(options, "unlocalize", ())
 
-
 class TableBase(object):
     """
     A representation of a table.
@@ -335,6 +342,15 @@ class TableBase(object):
         :type: `unicode`
 
 
+    .. attribute:: show_header
+
+        If `False`, the table will not have a header (`<thead>`), default
+        value is `True`
+
+        :type: `bool`
+
+
+
     .. attribute:: prefix
 
         A prefix for querystring fields to avoid name-clashes when using
@@ -381,7 +397,8 @@ class TableBase(object):
     def __init__(self, data, order_by=None, orderable=None, empty_text=None,
                  exclude=None, attrs=None, sequence=None, prefix=None,
                  order_by_field=None, page_field=None, per_page_field=None,
-                 template=None, sortable=None, default=None, request=None):
+                 template=None, sortable=None, default=None, request=None,
+                 show_header=None):
         super(TableBase, self).__init__()
         self.exclude = exclude or ()
         self.sequence = sequence
@@ -403,6 +420,7 @@ class TableBase(object):
         self.order_by_field = order_by_field
         self.page_field = page_field
         self.per_page_field = per_page_field
+        self.show_header = show_header
         # Make a copy so that modifying this will not touch the class
         # definition. Note that this is different from forms, where the
         # copy is made available in a ``fields`` attribute.
@@ -441,17 +459,21 @@ class TableBase(object):
         if request:
             RequestConfig(request).configure(self)
 
-    def as_html(self):
+    def as_html(self, request=None):
         """
-        Render the table to a simple HTML table.
-
-        If this method is used in the request/response cycle, any links
-        generated will clobber the querystring of the request. Use the
-        ``{% render_table %}`` template tag instead.
+        Render the table to a simple HTML table, adding `request` to the context.
         """
         template = get_template(self.template)
-        request = build_request()
-        return template.render(RequestContext(request, {'table': self}))
+
+        context = {'table': self}
+
+        if request:
+            if VERSION < (1, 8):
+                context = RequestContext(request, context)
+            else:
+                context['request'] = request
+
+        return template.render(context)
 
     @property
     def attrs(self):
@@ -461,6 +483,15 @@ class TableBase(object):
     def attrs(self, value):
         self._attrs = value
 
+    @property
+    def show_header(self):
+        return (self._show_header if self._show_header is not None
+                else self._meta.show_header)
+
+    @show_header.setter
+    def show_header(self, value):
+        self._show_header = value
+
     @property
     def empty_text(self):
         return self._empty_text
