@@ -1,13 +1,13 @@
 # coding: utf-8
 from __future__ import absolute_import, unicode_literals
-from django.core.handlers.wsgi import WSGIRequest
+
+import inspect
+import warnings
+from itertools import chain
+
+import six
 from django.utils.html import escape
 from django.utils.safestring import mark_safe
-from django.test.client import FakePayload
-from itertools import chain
-import inspect
-import six
-import warnings
 
 
 def python_2_unicode_compatible(klass):
@@ -151,7 +151,7 @@ class OrderByTuple(tuple):
             transformed.append(item)
         return super(OrderByTuple, cls).__new__(cls, transformed)
 
-    def __unicode__(self):
+    def __str__(self):
         return ','.join(self)
 
     def __contains__(self, name):
@@ -377,7 +377,8 @@ class Accessor(str):
                     if safe and getattr(current, 'alters_data', False):
                         raise ValueError('refusing to call %s() because `.alters_data = True`'
                                          % repr(current))
-                    current = current()
+                    if not getattr(current, 'do_not_call_in_templates', False):
+                        current = current()
                 # important that we break in None case, or a relationship
                 # spanning across a null-key will raise an exception in the
                 # next iteration, instead of defaulting.
@@ -425,16 +426,6 @@ class AttributeDict(dict):
                                    for k, v in six.iteritems(self)]))
 
 
-class Attrs(dict):
-    """
-    Backwards compatibility, deprecated.
-    """
-    def __init__(self, *args, **kwargs):
-        super(Attrs, self).__init__(*args, **kwargs)
-        warnings.warn("Attrs class is deprecated, use dict instead.",
-                      DeprecationWarning)
-
-
 def segment(sequence, aliases):
     """
     Translates a flat sequence of items into a set of prefixed aliases.
@@ -497,34 +488,6 @@ getargspec = getattr(inspect, next(funcs))
 del funcs
 
 
-def build_request(uri='/'):
-    """
-    Return a fresh HTTP GET / request.
-
-    This is essentially a heavily cutdown version of Django 1.3's
-    `~django.test.client.RequestFactory`.
-    """
-    path, _, querystring = uri.partition('?')
-    return WSGIRequest({
-        'CONTENT_TYPE':      'text/html; charset=utf-8',
-        'PATH_INFO':         path,
-        'QUERY_STRING':      querystring,
-        'REMOTE_ADDR':       '127.0.0.1',
-        'REQUEST_METHOD':    'GET',
-        'SCRIPT_NAME':       '',
-        'SERVER_NAME':       'testserver',
-        'SERVER_PORT':       '80',
-        'SERVER_PROTOCOL':   'HTTP/1.1',
-        'wsgi.version':      (1, 0),
-        'wsgi.url_scheme':   'http',
-        'wsgi.input':        FakePayload(b''),
-        'wsgi.errors':       six.StringIO(),
-        'wsgi.multiprocess': True,
-        'wsgi.multithread':  False,
-        'wsgi.run_once':     False,
-    })
-
-
 def total_ordering(cls):
     """Class decorator that fills in missing ordering methods"""
     convert = {
