@@ -1,10 +1,11 @@
 # coding: utf-8
 from __future__ import unicode_literals
+
+import six
+from django.core.urlresolvers import reverse
 from django.db import models
 from django.utils.safestring import mark_safe
-from django.utils.translation import ugettext_lazy
-from django.utils.translation import ugettext
-import six
+from django.utils.translation import ugettext, ugettext_lazy
 
 
 class Person(models.Model):
@@ -38,6 +39,16 @@ class Person(models.Model):
     def name(self):
         return "%s %s" % (self.first_name, self.last_name)
 
+    def get_absolute_url(self):
+        return reverse('person', args=(self.pk, ))
+
+
+class PersonProxy(Person):
+
+    class Meta:
+        proxy = True
+        ordering = ('last_name',)
+
 
 class Occupation(models.Model):
     name = models.CharField(max_length=200)
@@ -55,6 +66,11 @@ class Region(models.Model):
         return self.name
 
 
+class PersonInformation(models.Model):
+    person = models.ForeignKey(
+        Person, related_name='info_list', verbose_name='Information')
+
+
 # -- haystack -----------------------------------------------------------------
 
 if not six.PY3:  # Haystack isn't compatible with Python 3
